# redrover-api
Access Red Rover data via this REST API for Organizations that have granted you access.

# Authentication
The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.

This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.

Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.

# API Information
## Api Key
Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.

You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.

## Identifier
Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pike character`|` (e.g. `|ABC123`).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.6.2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/edustaff/redrover-api.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/edustaff/redrover-api.git`)

Then import the package:
```python
import redrover_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import redrover_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import redrover_api
from pprint import pprint
from redrover_api.api import absence_api
from redrover_api.model.absence_request import AbsenceRequest
from redrover_api.model.absence_response import AbsenceResponse
from redrover_api.model.bad_request_result import BadRequestResult
from redrover_api.model.not_found_result import NotFoundResult
from redrover_api.model.problem_details import ProblemDetails
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = redrover_api.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basic
configuration = redrover_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)


# Enter a context with an instance of the API client
with redrover_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = absence_api.AbsenceApi(api_client)
    org_id = 1 # int | The Red Rover Id of the Organization
    absence_request = AbsenceRequest(
        external_id="external_id_example",
        employee=Int32LocatorRequest(
            id=1,
            external_id="external_id_example",
        ),
        notes_to_approver="notes_to_approver_example",
        admin_only_notes="admin_only_notes_example",
        details=[
            AbsenceDetailCreateRequest(
                date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                day_part="Invalid",
                description="description_example",
                start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                reasons=[
                    AbsenceReasonUsageCreateRequest(
                        id=1,
                        external_id="external_id_example",
                        usage="usage_example",
                        daily_amount=3.14,
                        hourly_amount=3.14,
                    ),
                ],
            ),
        ],
        start_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
        end_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
    ) # AbsenceRequest | The details of the Absence

    try:
        # Create new Absence
        api_response = api_instance.create_absence(org_id, absence_request)
        pprint(api_response)
    except redrover_api.ApiException as e:
        print("Exception when calling AbsenceApi->create_absence: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AbsenceApi* | [**create_absence**](docs/AbsenceApi.md#create_absence) | **POST** /api/v1/{orgId}/Absence | Create new Absence
*AbsenceApi* | [**delete_absence**](docs/AbsenceApi.md#delete_absence) | **DELETE** /api/v1/{orgId}/Absence/{identifier} | Delete an Absence
*AbsenceApi* | [**get_absence**](docs/AbsenceApi.md#get_absence) | **GET** /api/v1/{orgId}/Absence/{identifier} | Get Absence
*AbsenceApi* | [**get_absences**](docs/AbsenceApi.md#get_absences) | **GET** /api/v1/{orgId}/Absence | Get list of Absences
*AbsenceApi* | [**update_absence**](docs/AbsenceApi.md#update_absence) | **PUT** /api/v1/{orgId}/Absence/{identifier} | Update existing Absence
*AbsenceReasonApi* | [**get_absence_reason**](docs/AbsenceReasonApi.md#get_absence_reason) | **GET** /api/v1/{orgId}/AbsenceReason/{identifier} | Get Absence Reason
*AbsenceReasonApi* | [**get_absence_reasons**](docs/AbsenceReasonApi.md#get_absence_reasons) | **GET** /api/v1/{orgId}/AbsenceReason | Get list of Absence Reasons
*AbsenceReasonBalanceApi* | [**create_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#create_absence_reason_balance) | **POST** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances | Create Absence Reason Balance
*AbsenceReasonBalanceApi* | [**delete_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#delete_absence_reason_balance) | **DELETE** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Delete Absence Reason Balance
*AbsenceReasonBalanceApi* | [**get_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#get_absence_reason_balance) | **GET** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Get Absence Reason Balance
*AbsenceReasonBalanceApi* | [**get_absence_reason_balances**](docs/AbsenceReasonBalanceApi.md#get_absence_reason_balances) | **GET** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances | Get Absence Reason Balances
*AbsenceReasonBalanceApi* | [**update_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#update_absence_reason_balance) | **PUT** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Update Absence Reason Balance
*ConnectionApi* | [**download_report**](docs/ConnectionApi.md#download_report) | **GET** /api/v1/{orgId}/Connection/{id}/download | Download Report
*ConnectionApi* | [**download_report_0**](docs/ConnectionApi.md#download_report_0) | **POST** /api/v1/{orgId}/Connection/{id}/download | Download Report
*ConnectionApi* | [**post_report_data**](docs/ConnectionApi.md#post_report_data) | **POST** /api/v1/{orgId}/Connection/{id}/data | Posts Report
*ConnectionApi* | [**run_report**](docs/ConnectionApi.md#run_report) | **POST** /api/v1/{orgId}/Connection/{id}/run | Run Report
*OrganizationApi* | [**get_current_school_years**](docs/OrganizationApi.md#get_current_school_years) | **GET** /api/v1/Organization/{id}/schoolYear/current | Get current School Year
*OrganizationApi* | [**get_organization**](docs/OrganizationApi.md#get_organization) | **GET** /api/v1/Organization | Get Organizations
*OrganizationApi* | [**get_organization_0**](docs/OrganizationApi.md#get_organization_0) | **GET** /api/v1/Organization/{id} | Get Organization
*OrganizationApi* | [**get_school_years**](docs/OrganizationApi.md#get_school_years) | **GET** /api/v1/Organization/{id}/schoolYear | Get School Years
*ReferenceDataApi* | [**gets_attributes**](docs/ReferenceDataApi.md#gets_attributes) | **GET** /api/v1/{orgId}/ReferenceData/attribute | Get Attributes
*ReferenceDataApi* | [**gets_attributes_0**](docs/ReferenceDataApi.md#gets_attributes_0) | **POST** /api/v1/{orgId}/ReferenceData/attribute | Create attribute
*UserApi* | [**create_substitute**](docs/UserApi.md#create_substitute) | **PUT** /api/v1/{orgId}/User/substitute | Creates / Updates Substitute
*UserApi* | [**create_substitute_0**](docs/UserApi.md#create_substitute_0) | **POST** /api/v1/{orgId}/User/substitute | Creates / Updates Substitute
*UserApi* | [**creates_admin**](docs/UserApi.md#creates_admin) | **PUT** /api/v1/{orgId}/User/administrator | Creates / Updates Administrator
*UserApi* | [**creates_admin_0**](docs/UserApi.md#creates_admin_0) | **POST** /api/v1/{orgId}/User/administrator | Creates / Updates Administrator
*UserApi* | [**creates_employee**](docs/UserApi.md#creates_employee) | **PUT** /api/v1/{orgId}/User/employee | Creates / Updates Employee
*UserApi* | [**creates_employee_0**](docs/UserApi.md#creates_employee_0) | **POST** /api/v1/{orgId}/User/employee | Creates / Updates Employee
*UserApi* | [**deletes_user**](docs/UserApi.md#deletes_user) | **DELETE** /api/v1/{orgId}/User/user/{id} | Deletes User
*UserApi* | [**get_substitute**](docs/UserApi.md#get_substitute) | **GET** /api/v1/{orgId}/User/substitute/{id} | Get Substitute by Id
*UserApi* | [**get_substitutes**](docs/UserApi.md#get_substitutes) | **GET** /api/v1/{orgId}/User/substitute | Query for Substitutes
*UserApi* | [**gets_admin**](docs/UserApi.md#gets_admin) | **GET** /api/v1/{orgId}/User/administrator/{id} | Gets Administrator
*UserApi* | [**gets_employee**](docs/UserApi.md#gets_employee) | **GET** /api/v1/{orgId}/User/employee/{id} | Gets Employee
*VacancyApi* | [**get_vacancy_details**](docs/VacancyApi.md#get_vacancy_details) | **GET** /api/v1/{orgId}/Vacancy/vacancyDetails |  Query Vacancy Details
*WebhooksApi* | [**create_webhook**](docs/WebhooksApi.md#create_webhook) | **POST** /api/v1/Webhooks | Create Webhook.
*WebhooksApi* | [**delete_webhook**](docs/WebhooksApi.md#delete_webhook) | **DELETE** /api/v1/Webhooks/{id} | Delete Webhook
*WebhooksApi* | [**get_webhook**](docs/WebhooksApi.md#get_webhook) | **GET** /api/v1/Webhooks | Get Webhooks
*WebhooksApi* | [**get_webhook_0**](docs/WebhooksApi.md#get_webhook_0) | **GET** /api/v1/Webhooks/{identifier} | Get Webhook
*WebhooksApi* | [**put_webhook_uri**](docs/WebhooksApi.md#put_webhook_uri) | **PUT** /api/v1/Webhooks/{id} | Update Webhook


## Documentation For Models

 - [AbsenceDetailCreateRequest](docs/AbsenceDetailCreateRequest.md)
 - [AbsenceDetailResponse](docs/AbsenceDetailResponse.md)
 - [AbsenceReasonBalanceCreateRequest](docs/AbsenceReasonBalanceCreateRequest.md)
 - [AbsenceReasonBalanceResponse](docs/AbsenceReasonBalanceResponse.md)
 - [AbsenceReasonBalanceUpdateRequest](docs/AbsenceReasonBalanceUpdateRequest.md)
 - [AbsenceReasonCategoryResponse](docs/AbsenceReasonCategoryResponse.md)
 - [AbsenceReasonResponse](docs/AbsenceReasonResponse.md)
 - [AbsenceReasonUsageCreateRequest](docs/AbsenceReasonUsageCreateRequest.md)
 - [AbsenceReasonUsageResponse](docs/AbsenceReasonUsageResponse.md)
 - [AbsenceRequest](docs/AbsenceRequest.md)
 - [AbsenceResponse](docs/AbsenceResponse.md)
 - [AccessControlRequest](docs/AccessControlRequest.md)
 - [AccessControlResponse](docs/AccessControlResponse.md)
 - [AccountingCode](docs/AccountingCode.md)
 - [AccountingCodeAllocation](docs/AccountingCodeAllocation.md)
 - [AccountingCodeAllocationRequest](docs/AccountingCodeAllocationRequest.md)
 - [AdministratorRequest](docs/AdministratorRequest.md)
 - [AdministratorResponse](docs/AdministratorResponse.md)
 - [Assembly](docs/Assembly.md)
 - [AttributeRequest](docs/AttributeRequest.md)
 - [AttributeResponse](docs/AttributeResponse.md)
 - [AuthenticationProperties](docs/AuthenticationProperties.md)
 - [BadRequestResult](docs/BadRequestResult.md)
 - [ConstructorInfo](docs/ConstructorInfo.md)
 - [CustomAttributeData](docs/CustomAttributeData.md)
 - [CustomAttributeNamedArgument](docs/CustomAttributeNamedArgument.md)
 - [CustomAttributeTypedArgument](docs/CustomAttributeTypedArgument.md)
 - [EmployeeRequest](docs/EmployeeRequest.md)
 - [EmployeeResponse](docs/EmployeeResponse.md)
 - [EventInfo](docs/EventInfo.md)
 - [FieldInfo](docs/FieldInfo.md)
 - [ForbidResult](docs/ForbidResult.md)
 - [Int32LocatorRequest](docs/Int32LocatorRequest.md)
 - [Int32LocatorResponse](docs/Int32LocatorResponse.md)
 - [MemberInfo](docs/MemberInfo.md)
 - [MethodBase](docs/MethodBase.md)
 - [MethodInfo](docs/MethodInfo.md)
 - [Module](docs/Module.md)
 - [ModuleHandle](docs/ModuleHandle.md)
 - [NotFoundResult](docs/NotFoundResult.md)
 - [OkObjectResult](docs/OkObjectResult.md)
 - [OkResult](docs/OkResult.md)
 - [OrgUserEmployeeResponse](docs/OrgUserEmployeeResponse.md)
 - [OrganizationResponse](docs/OrganizationResponse.md)
 - [ParameterInfo](docs/ParameterInfo.md)
 - [PayCode](docs/PayCode.md)
 - [PositionJobRequest](docs/PositionJobRequest.md)
 - [PositionRequest](docs/PositionRequest.md)
 - [PositionScheduleCustomVariantRequest](docs/PositionScheduleCustomVariantRequest.md)
 - [PositionScheduleItemRequest](docs/PositionScheduleItemRequest.md)
 - [PositionScheduleRequest](docs/PositionScheduleRequest.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [PropertyInfo](docs/PropertyInfo.md)
 - [Reason](docs/Reason.md)
 - [RuntimeFieldHandle](docs/RuntimeFieldHandle.md)
 - [RuntimeMethodHandle](docs/RuntimeMethodHandle.md)
 - [RuntimeTypeHandle](docs/RuntimeTypeHandle.md)
 - [SchoolYearResponse](docs/SchoolYearResponse.md)
 - [SimpleAbsenceDetail](docs/SimpleAbsenceDetail.md)
 - [SimpleLocation](docs/SimpleLocation.md)
 - [SimplePerson](docs/SimplePerson.md)
 - [SimplePosition](docs/SimplePosition.md)
 - [StructLayoutAttribute](docs/StructLayoutAttribute.md)
 - [SubstituteAttributeRequest](docs/SubstituteAttributeRequest.md)
 - [SubstituteAttributeResponse](docs/SubstituteAttributeResponse.md)
 - [SubstitutePreferencesRequest](docs/SubstitutePreferencesRequest.md)
 - [SubstituteRelatedOrgRequest](docs/SubstituteRelatedOrgRequest.md)
 - [SubstituteRequest](docs/SubstituteRequest.md)
 - [SubstituteResponse](docs/SubstituteResponse.md)
 - [TimeOffBalanceRequest](docs/TimeOffBalanceRequest.md)
 - [TimeSpan](docs/TimeSpan.md)
 - [Type](docs/Type.md)
 - [TypeInfo](docs/TypeInfo.md)
 - [VacancyDetailResponse](docs/VacancyDetailResponse.md)
 - [WebhookCreateRequest](docs/WebhookCreateRequest.md)
 - [WebhookResponse](docs/WebhookResponse.md)
 - [WebhookUpdateRequest](docs/WebhookUpdateRequest.md)


## Documentation For Authorization


## basic

- **Type**: HTTP basic authentication


## Author

dev@redroverk12.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in redrover_api.apis and redrover_api.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from redrover_api.api.default_api import DefaultApi`
- `from redrover_api.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import redrover_api
from redrover_api.apis import *
from redrover_api.models import *
```

